@@ -3,5 +3,5 @@ from .exceptions import ClientError, ImageError, ServerNotResponsiveError
 
 __name__ = "rustplus"
 __author__ = "olijefferson"
-__version__ = "2.1.1"
-__support__ = "Discord: Ollie#0175"
\ No newline at end of file
+__version__ = "2.2.2"
+__support__ = "Discord: https://discord.gg/nQqJe8qvP8"
\ No newline at end of file
