@@ -3,6 +3,7 @@ from PIL import Image
 from io import BytesIO
 from collections import defaultdict
 from datetime import datetime
+from importlib import resources
 
 from .rustplus_pb2 import *
 from ..utils import *
@@ -19,6 +20,9 @@ class RustSocket:
         self.steamid = steamid
         self.playertoken = playertoken
 
+    def __str__(self) -> str:
+        return "RustSocket: ip = {} | port = {} | steamid = {} | playertoken = {}".format(self.ip, self.port, self.steamid, self.playertoken)
+
     def __initProto(self) -> AppRequest:
         request = AppRequest()
         request.seq = self.seq
@@ -261,7 +265,7 @@ class RustSocket:
         returnDict = {}
 
         targetTime = datetime.utcfromtimestamp(int(returnedData.response.entityInfo.payload.protectionExpiry))
-        difference = targetTime - datetime.now()
+        difference = targetTime - datetime.utcnow()
 
         returnDict["protectionTime"] = difference
         returnDict["hasProtection"] = bool(returnedData.response.entityInfo.payload.hasProtection)
@@ -296,6 +300,15 @@ class RustSocket:
         returnDict["contents"] = items
         return returnDict
 
+    def __getCurrentEvents(self):
+
+        mapMarkers = list(self.__getMarkers().response.mapMarkers.markers)
+        poi = []
+        for marker in mapMarkers:
+            if marker.type == 2 or marker.type == 4 or marker.type == 5 or marker.type == 6:
+                poi.append(marker)
+        return poi
+
     ################################################
 
     def connect(self) -> None:
@@ -344,7 +357,7 @@ class RustSocket:
 
         return outData
 
-    def getMap(self, addicons : bool = False) -> Image:
+    def getMap(self, addIcons : bool = False, addEvents : bool = False, addVendingMachines : bool = False) -> Image:
         """
         Returns the Map of the server with the option to add icons.
         """
@@ -352,13 +365,46 @@ class RustSocket:
 
         map, monuments = self.__getMap(MAPSIZE)
 
-        if addicons:
-            monument_name_converter = MonumentNameToImage()
+        if addIcons or addEvents or addVendingMachines:
             cood_formatter = CoordUtil()
+
+        if addIcons:
+            monument_name_converter = MonumentNameToImage()
             for monument in monuments:
+                if str(monument.token) == "DungeonBase":
+                    continue
                 icon = monument_name_converter.convert(monument.token)
+                icon = icon.resize((150, 150))
+                if str(monument.token) == "train_tunnel_display_name":
+                    icon = icon.resize((100, 125))
                 map.paste(icon, (cood_formatter.format(int(monument.x), int(monument.y), MAPSIZE)), icon)
 
+        mapMarkers = list(self.__getMarkers().response.mapMarkers.markers)
+
+        if addVendingMachines:
+            with resources.path("rustplus.api.icons", "vending_machine.png") as path:
+                vendingMachine = Image.open(path).convert("RGBA")
+                vendingMachine = vendingMachine.resize((100, 100))
+
+        for marker in mapMarkers:
+            if addEvents:
+                markerConverter = MapMarkerConverter()
+                if marker.type == 2 or marker.type == 4 or marker.type == 5 or marker.type == 6:
+                    icon = markerConverter.convert(str(marker.type), marker.rotation)
+                    if marker.type == 6:
+                        x = marker.x
+                        y = marker.y
+                        if y > MAPSIZE: y = MAPSIZE
+                        if y < 0: y = 100
+                        if x > MAPSIZE: x = MAPSIZE - 75
+                        if x < 0: x = 50
+                        map.paste(icon, (int(x), MAPSIZE - int(y)), icon)
+                    else:
+                        map.paste(icon, (cood_formatter.format(int(marker.x), int(marker.y), MAPSIZE)), icon)
+            if addVendingMachines:
+                if marker.type == 3:
+                    map.paste(vendingMachine, (int(marker.x) - 50, MAPSIZE - int(marker.y) - 50), vendingMachine)
+
         map = map.resize((2000, 2000), Image.ANTIALIAS)
 
         return map
@@ -460,3 +506,17 @@ class RustSocket:
         """
         
         return self.__getTCStorage(EID, combineStacks)
+
+    def getCurrentEvents(self) -> list:
+        """
+        Gets all current ongoing events on the map
+        Can detect:
+            - Explosion
+            - CH47 (Chinook)
+            - Cargo Ship
+            - Locked Crate
+
+        Returns the MapMarker for the event
+        """
+        
+        return self.__getCurrentEvents()
\ No newline at end of file
